/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.sqlPlugin;

import org.jdom.Element;

import com.intellij.openapi.components.ProjectComponent;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.util.InvalidDataException;
import com.intellij.openapi.util.JDOMExternalizable;
import com.intellij.openapi.util.WriteExternalException;
import com.intellij.openapi.wm.ToolWindowAnchor;
import com.intellij.openapi.wm.ToolWindowManager;
import com.intellij.openapi.wm.ToolWindow;

import com.kiwisoft.db.DatabaseManager;
import com.kiwisoft.db.QueryManager;
import com.kiwisoft.utils.gui.IconManager;
import com.kiwisoft.sqlPlugin.browser.BrowserPanel;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.4 $, $Date: 2005/08/10 18:54:14 $
 */
public class SQLQueryPlugin implements ProjectComponent, JDOMExternalizable
{
	private Project project;

	public static final String SQL_TOOL_WINDOW = "SQL";
	public static final String BROWSER_TOOL_WINDOW = "SQL Schema";

	public SQLQueryPlugin(Project project)
	{
		this.project = project;
	}

	public void projectOpened()
	{
		initToolWindow();
	}

	public void projectClosed()
	{
		unregisterToolWindow();
	}

	public void initComponent()
	{
	}

	public void disposeComponent()
	{
	}

	public String getComponentName()
	{
		return "SQL";
	}

	public void readExternal(Element element) throws InvalidDataException
	{
		try
		{
			CommonConfiguration.getInstance(project).readExternal(element, project);
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}
	}

	public void writeExternal(Element element) throws WriteExternalException
	{
		try
		{
			CommonConfiguration.getInstance(project).writeExternal(element, project);
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}
	}

	private void initToolWindow()
	{
		ToolWindowManager toolWindowManager = ToolWindowManager.getInstance(project);

		ToolWindow toolWindow=toolWindowManager.registerToolWindow(SQL_TOOL_WINDOW, SQLPluginPanel.getInstance(project, true), ToolWindowAnchor.BOTTOM);
		toolWindow.setTitle("SQL");
		toolWindow.setIcon(IconManager.getIcon(getClass().getClassLoader(), IconNames.APPLICATION));
	}

	private void unregisterToolWindow()
	{
		// Unregister all project specific components
		DatabaseManager.closeInstance(project);
		QueryManager.closeInstance(project);
		CommonConfiguration.closeInstance(project);
		SQLPluginPanel.closeInstance(project);
		BrowserPanel.closeInstance(project);

		// Unregister all tool windows
		ToolWindowManager toolWindowManager = ToolWindowManager.getInstance(project);
		if (toolWindowManager.getToolWindow(SQL_TOOL_WINDOW)!=null) toolWindowManager.unregisterToolWindow(SQL_TOOL_WINDOW);
		if (toolWindowManager.getToolWindow(BROWSER_TOOL_WINDOW)!=null) toolWindowManager.unregisterToolWindow(BROWSER_TOOL_WINDOW);
	}
}