/*
 * Copyright (C) 2002-2003 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.sqlPlugin.actions;

import java.awt.*;
import java.awt.event.ActionEvent;
import java.util.*;
import javax.swing.*;
import javax.swing.table.TableColumn;
import javax.swing.table.TableColumnModel;

import com.intellij.openapi.project.Project;

import com.kiwisoft.utils.gui.table.SortableTable;
import com.kiwisoft.utils.gui.IconManager;
import com.kiwisoft.utils.idea.DialogStub;
import com.kiwisoft.utils.idea.DialogWrapper;
import com.kiwisoft.utils.Utils;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.1 $, $Date: 2005/10/29 11:17:39 $
 */
public class ManageColumnsAction extends AbstractAction
{
	private Project project;
	private SortableTable table;

	public ManageColumnsAction(Project project, SortableTable table)
	{
		super("Manage Columns...", IconManager.ICON_16X16);
		this.project=project;
		this.table=table;
	}

	public void actionPerformed(ActionEvent e)
	{
		Utils.wrapDialog(project, new ManageColumnsDialogStub(), true, true);
	}

	public class ManageColumnsDialogStub implements DialogStub
	{
		private Map columns;

		private DialogWrapper dialogWrapper;
		private JPanel pnlContent;

		public ManageColumnsDialogStub()
		{
			initializeComponents();
		}

		public String getTitle()
		{
			return "Manage Columns";
		}

		public void setDialogWrapper(DialogWrapper dialogWrapper)
		{
			this.dialogWrapper=dialogWrapper;
		}

		public JComponent getPreferredFocusedComponent()
		{
			return null;
		}

		public Action[] getActions()
		{
			return new Action[]{new ApplyAction(), new CancelAction()};
		}

		public JComponent getContentPanel()
		{
			return pnlContent;
		}

		public void dispose()
		{
		}

		private void initializeComponents()
		{
			columns=new TreeMap(new Comparator()
			{
				public int compare(Object o1, Object o2)
				{
					TableColumn column1=(TableColumn)o1;
					TableColumn column2=(TableColumn)o2;
					return column1.getModelIndex()-column2.getModelIndex();
				}
			});
			JPanel panel=new JPanel(new GridBagLayout());

			TableColumnModel columnModel=table.getColumnModel();
			for (int i=0;i<columnModel.getColumnCount();i++)
			{
				TableColumn column=columnModel.getColumn(i);
				JCheckBox checkBox=new JCheckBox(String.valueOf(column.getHeaderValue()), true);
				columns.put(column, checkBox);
			}
			for (Iterator it=table.getHiddenColumns().iterator(); it.hasNext();)
			{
				TableColumn column=(TableColumn)it.next();
				JCheckBox checkBox=new JCheckBox(String.valueOf(column.getHeaderValue()), false);
				columns.put(column, checkBox);
			}

			int row=0;
			for (Iterator it=columns.values().iterator(); it.hasNext();)
			{
				JCheckBox checkBox=(JCheckBox)it.next();
				panel.add(checkBox, new GridBagConstraints(0, row++, 1, 1, 0.0, 0.0,
														   GridBagConstraints.WEST, GridBagConstraints.NONE,
														   new Insets(3, 3, 0, 3), 0, 0));
			}

			JScrollPane scrollPane=new JScrollPane(panel);
			scrollPane.setPreferredSize(new Dimension(400, 300));

			pnlContent=new JPanel(new BorderLayout());
			pnlContent.add(scrollPane, BorderLayout.CENTER);
		}

		private class ApplyAction extends AbstractAction
		{
			public ApplyAction()
			{
				super("Apply");
				putValue(DEFAULT_ACTION, Boolean.TRUE);
			}

			public void actionPerformed(ActionEvent e)
			{
				for (Iterator it=columns.entrySet().iterator(); it.hasNext();)
				{
					Map.Entry entry=(Map.Entry)it.next();
					TableColumn column=(TableColumn)entry.getKey();
					JCheckBox checkBox=(JCheckBox)entry.getValue();
					if (checkBox.isSelected())
					{
						if (table.getHiddenColumns().contains(column)) table.showColumn(column);
					}
					else
					{
						if (!table.getHiddenColumns().contains(column)) table.hideColumn(column);
					}
				}
				dialogWrapper.dispose();
			}
		}

		private class CancelAction extends AbstractAction
		{
			public CancelAction()
			{
				super("Cancel");
			}

			public void actionPerformed(ActionEvent e)
			{
				dialogWrapper.dispose();
			}
		}
	}
}
