/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.sqlPlugin.config;

import org.jdom.Element;

import com.intellij.openapi.application.Application;
import com.intellij.openapi.application.ApplicationManager;
import com.intellij.openapi.components.ApplicationComponent;
import com.intellij.openapi.util.InvalidDataException;
import com.intellij.openapi.util.JDOMExternalizable;
import com.intellij.openapi.util.WriteExternalException;

import com.kiwisoft.db.driver.DatabaseDriverManager;
import com.kiwisoft.sqlPlugin.templates.TemplateManager;
import com.kiwisoft.utils.StringUtils;
import com.kiwisoft.utils.Utils;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.2 $, $Date: 2005/08/10 18:54:52 $
 */
public class SQLPluginAppConfig implements ApplicationComponent, JDOMExternalizable
{
	private static SQLPluginAppConfig instance;

	public static SQLPluginAppConfig getInstance()
	{
		Application application=ApplicationManager.getApplication();
		if (application!=null)
		{
			Object component=application.getComponent(SQLPluginAppConfig.class);
			return (SQLPluginAppConfig)component;
		}
		else
		{
			if (instance==null)
			{
				instance=new SQLPluginAppConfig();
				instance.initComponent();
			}
			return instance;
		}
	}

	private ExportConfiguration export;

	public ExportConfiguration getExport()
	{
		if (export==null) export=new ExportConfiguration();
		return export;
	}

	private TableConfigurationAdapter tableAdapter;

	public TableConfigurationAdapter getTableAdapter()
	{
		if (tableAdapter==null) tableAdapter=new TableConfigurationAdapter();
		return tableAdapter;
	}

	public String getDriversPath()
	{
		return DatabaseDriverManager.getDriversPath();
	}

	public void setDriversPath(String newPath)
	{
		DatabaseDriverManager.setDriversPath(newPath);
	}

	private boolean keepConnectionOpen;

	public boolean isKeepConnectionOpen()
	{
		return keepConnectionOpen;
	}

	public void setKeepConnectionOpen(boolean keepConnectionOpen)
	{
		this.keepConnectionOpen=keepConnectionOpen;
	}

	// ApplicationComponent interface

	public String getComponentName()
	{
		return "SQLPlugin.Configuration";
	}

	public void initComponent()
	{
	}

	public void disposeComponent()
	{
	}

	// JDOMExternalizable interface

	public void writeExternal(Element element) throws WriteExternalException
	{
		Element exportElement=new Element("export");
		element.addContent(exportElement);
		getExport().writeExternal(element);

		if (!StringUtils.isEmpty(getDriversPath()))
		{
			Element pathElement=new Element("driversPath");
			pathElement.setAttribute("value", getDriversPath());
			element.addContent(pathElement);
		}

		Element connectionElement=new Element("connections");
		connectionElement.setAttribute("keepOpen", Boolean.toString(keepConnectionOpen));
		element.addContent(connectionElement);

		Element tablesElement=new Element("tables");
		element.addContent(tablesElement);
		getTableAdapter().writeExternal(tablesElement);

		if (TemplateManager.hasInstance()) TemplateManager.getInstance().saveTemplates();
	}

	public void readExternal(Element element) throws InvalidDataException
	{
		Element exportElement=element.getChild("export");
		if (exportElement!=null) getExport().readExternal(exportElement);
		Element pathElement=element.getChild("driversPath");
		if (pathElement!=null) DatabaseDriverManager.setDriversPath(Utils.getString(pathElement, "value", null));
		Element connectionElement=element.getChild("connections");
		if (connectionElement!=null) setKeepConnectionOpen(Utils.getBoolean(connectionElement, "keepOpen", false));
		Element tablesElement=element.getChild("tables");
		if (tablesElement!=null) getTableAdapter().readExternal(tablesElement);
	}
}
