/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.utils.gui;

import java.awt.HeadlessException;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import javax.swing.*;

import com.kiwisoft.utils.idea.DialogStub;
import com.kiwisoft.utils.idea.DialogWrapper;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.2 $, $Date: 2005/08/10 18:55:43 $
 */
public class EditTextDialogStub implements DialogStub
{
	private DialogWrapper dialogWrapper;

	private JTextPane textPane;
	private JComponent pnlContent;
	private String text;
	private boolean returnValue;
	private String title;

	public EditTextDialogStub(String title, String text)
	{
		this.title=title;
		textPane=new JTextPane();
		textPane.setText(text);

		pnlContent=new JScrollPane(textPane);
		pnlContent.setPreferredSize(new Dimension(400, 300));
	}

	public EditTextDialogStub(String text) throws HeadlessException
	{
		this("Text Editor", text);
	}

	public String getTitle()
	{
		return title;
	}

	public String getText()
	{
		return text;
	}

	public boolean getReturnValue()
	{
		return returnValue;
	}

	public void setDialogWrapper(DialogWrapper dialogWrapper)
	{
		this.dialogWrapper=dialogWrapper;
	}

	public Action[] getActions()
	{
		return new Action[]{new ApplyAction(), new CancelAction()};
	}

	public void dispose()
	{
	}

	public JComponent getContentPanel()
	{
		return pnlContent;
	}

	public JComponent getPreferredFocusedComponent()
	{
		return textPane;
	}

	private class ApplyAction extends AbstractAction
	{
		public ApplyAction()
		{
			super("Ok");
			putValue(DEFAULT_ACTION, Boolean.TRUE);
		}

		public void actionPerformed(ActionEvent e)
		{
			text=textPane.getText();
			returnValue=true;
			dialogWrapper.dispose();
		}
	}

	private class CancelAction extends AbstractAction
	{
		public CancelAction()
		{
			super("Cancel");
		}

		public void actionPerformed(ActionEvent e)
		{
			returnValue=false;
			dialogWrapper.dispose();
		}
	}
}
