/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.utils.gui;

import java.awt.Component;
import java.awt.Image;
import java.awt.MediaTracker;
import java.awt.Toolkit;
import java.net.URL;
import javax.swing.ImageIcon;
import javax.swing.JLabel;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.3 $, $Date: 2005/08/10 18:55:43 $
 */
public class ImageTools
{
	private static Component mediaTracker=new JLabel();

	private ImageTools()
	{
	}

	public static ImageIcon loadIcon(String fileName)
	{
		Image image=loadImage(fileName);
		if (image!=null)
			return new ImageIcon(image);
		else
			return null;
	}

	public static ImageIcon loadIcon(URL url)
	{
		Image image=loadImage(url);
		if (image!=null)
			return new ImageIcon(image);
		else
			return null;
	}

	public static Image loadImage(String fileName)
	{
		if (fileName.startsWith("/")) fileName=fileName.substring(1, fileName.length());
		MediaTracker tracker=new MediaTracker(mediaTracker);
		Image image=Toolkit.getDefaultToolkit().getImage(fileName);
		tracker.addImage(image, 1);
		try
		{
			tracker.waitForID(1);
		}
		catch (InterruptedException e)
		{
			System.out.println("Interrupted while loading image: "+fileName);
			return null;
		}
		if (tracker.isErrorID(1))
		{
			return null;
		}
		return image;
	}

	public static Image loadImage(URL url)
	{
		MediaTracker tracker=new MediaTracker(mediaTracker);
		Image image=Toolkit.getDefaultToolkit().getImage(url);
		tracker.addImage(image, 1);
		try
		{
			tracker.waitForID(1);
		}
		catch (InterruptedException e)
		{
			System.out.println("Interrupted while loading image: "+url);
			return null;
		}
		if (tracker.isErrorID(1))
		{
			return null;
		}
		return image;
	}

}
