/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.utils.idea;

import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Frame;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import javax.swing.*;

import com.kiwisoft.utils.Utils;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.3 $, $Date: 2005/08/10 18:56:00 $
 */
public class DefaultDialogWrapper extends JDialog implements DialogWrapper
{
    private DialogStub dialogStub;

    public DefaultDialogWrapper(DialogStub dialogStub, boolean modal)
    {
        super((Frame)null, dialogStub.getTitle(), modal);
        this.dialogStub=dialogStub;
        dialogStub.setDialogWrapper(this);
        setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);

        JPanel pnlBottom=new JPanel(new FlowLayout(FlowLayout.RIGHT));
        Action[] actions=dialogStub.getActions();
	    JButton defaultButton=null;
        if (actions!=null)
        {
            for (int i=0; i<actions.length; i++)
            {
                Action action=actions[i];
				if (action!=null)
				{
					JButton button=new JButton(action);
					Dimension size=button.getPreferredSize();
					if (size.width<80)
						button.setPreferredSize(new Dimension(80, 25));
					pnlBottom.add(button);
					if (action.getValue(DialogStub.DEFAULT_ACTION)!=null) defaultButton=button;
				}
				else
				{
					throw new UnsupportedOperationException("Not supported by IntelliJ DialogWrapper.");
//					pnlBottom.add(new JSeparator());
				}
			}
        }

        JPanel pnlContent=new JPanel(new GridBagLayout());
        pnlContent.add(dialogStub.getContentPanel(),
            new GridBagConstraints(0, 0, 1, 1, 1.0, 1.0, GridBagConstraints.WEST, GridBagConstraints.BOTH, new Insets(3, 3, 3, 3), 0, 0));
        pnlContent.add(pnlBottom,
            new GridBagConstraints(0, 1, 1, 1, 1.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.BOTH, new Insets(3, 3, 3, 3), 0, 0));

        setContentPane(pnlContent);
	    if (defaultButton!=null) getRootPane().setDefaultButton(defaultButton);
        pack();
    }

    public void show()
    {
        Utils.arrangeWindow(null, this);
		JComponent focusComponent=dialogStub.getPreferredFocusedComponent();
		if (focusComponent!=null) focusComponent.requestFocus();
        super.show();
    }

    public void dispose()
    {
        dialogStub.dispose();
        super.dispose();
    }
}
