/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.utils;

import java.util.Arrays;

import junit.framework.TestCase;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.3 $, $Date: 2005/08/10 18:50:43 $
 */
public class StringUtilsTest extends TestCase
{
	public StringUtilsTest(String s)
	{
		super(s);
	}

	public void testToByte()
	{
		assertEquals(0x20, StringUtils.toByte("#20"));
		assertEquals(0x3b, StringUtils.toByte("#3b"));
		assertEquals(0x20, StringUtils.toByte("0x20"));
		assertEquals(0x3b, StringUtils.toByte("0x3b"));
		assertEquals(0x20, StringUtils.toByte("20"));
		assertEquals(0x3b, StringUtils.toByte("3b"));
	}

	public void testToByteArray()
	{
		assertTrue(Arrays.equals(new byte[]{0x21, 0x32, 0x43}, StringUtils.toByteArray("213243")));
	}

	public void testToByteString()
	{
		assertEquals("213243", StringUtils.toByteString(new byte[]{0x21,0x32,0x43}, null));
		assertEquals("21 32 43", StringUtils.toByteString(new byte[]{0x21,0x32,0x43}, " "));
	}

	public void testConvertJavaString()
	{
		assertEquals("abc", StringUtils.convertJavaString("abc"));
		assertEquals("abc", StringUtils.convertJavaString("\"abc\""));
		assertEquals("abc\nabc", StringUtils.convertJavaString("\"abc\"\n+\"abc\""));
		assertEquals("abc\nabc", StringUtils.convertJavaString("\"abc\nabc\""));
		assertEquals("abc\nabc", StringUtils.convertJavaString("\"abc\\nabc\""));
		assertEquals("abc\nabc", StringUtils.convertJavaString("\"abc\"\n\t +\"abc\""));
		assertEquals("abc", StringUtils.convertJavaString("\"abc\"\n/"));
		assertEquals("abc\n/", StringUtils.convertJavaString("abc\n/"));
	}
}
